@@ -86,6 +86,8 @@ extern int afs_shuttingdown;
 #define	AFS_NRXPACKETS	80
 #define	AFS_RXDEADTIME	50
 #define AFS_HARDDEADTIME	120
+#define AFS_BLKBITS	12
+#define AFS_BLKSIZE	(1 << AFS_BLKBITS)
 
 extern afs_int32 afs_rx_deadtime;
 extern afs_int32 afs_rx_harddead;
