@@ -1,5 +1,5 @@
 /* 
- * $Id: aklog_main.c,v 1.1.2.14 2006/08/29 19:19:05 shadow Exp $
+ * $Id: aklog_main.c,v 1.1.2.15 2007/02/10 13:56:54 jaltman Exp $
  *
  * Copyright 1990,1991 by the Massachusetts Institute of Technology
  * For distribution and copying rights, see the file "mit-copyright.h"
@@ -7,7 +7,7 @@
 
 #if !defined(lint) && !defined(SABER)
 static char *rcsid =
-	"$Id: aklog_main.c,v 1.1.2.14 2006/08/29 19:19:05 shadow Exp $";
+	"$Id: aklog_main.c,v 1.1.2.15 2007/02/10 13:56:54 jaltman Exp $";
 #endif /* lint || SABER */
 
 #include <afsconfig.h>
@@ -158,7 +158,7 @@ extern int pioctl(char *, afs_int32, struct ViceIoctl *, afs_int32);
  * Other prototypes
  */
 
-extern char *afs_realm_of_cell(krb5_context, struct afsconf_cell *);
+extern char *afs_realm_of_cell(krb5_context, struct afsconf_cell *, int);
 static int isdir(char *, unsigned char *);
 static krb5_error_code get_credv5(krb5_context context, char *, char *,
 				  char *, krb5_creds **);
@@ -496,20 +496,24 @@ static int auth_to_cell(krb5_context context, char *cell, char *realm)
 	    }
 	}
 	else {
-	    char *realm = afs_realm_of_cell(context, &ak_cellconfig);
+	    char *afs_realm = afs_realm_of_cell(context, &ak_cellconfig, FALSE);
 
-	    if (!realm) {
+	    if (!afs_realm) {
 		fprintf(stderr, 
 			"%s: Couldn't figure out realm for cell %s.\n",
 			progname, cell_to_use);
 		exit(AKLOG_MISC);
 	    }
 
-	    strcpy(realm_of_cell, realm);
+	    strcpy(realm_of_cell, afs_realm);
 
 	    if (dflag) {
-		printf("We've deduced that we need to authenticate to"
-		       " realm %s.\n", realm_of_cell);
+		if (realm_of_cell[0])
+		    printf("We've deduced that we need to authenticate to"
+			   " realm %s.\n", realm_of_cell);
+		else
+		    printf("We've deduced that we need to authenticate "
+			   "using referrals.\n");
 	    }
 	}
 
@@ -563,18 +567,50 @@ static int auth_to_cell(krb5_context context, char *cell, char *realm)
 	 */
 
 	if (dflag) {
-	    printf("Getting tickets: %s/%s@%s\n", name,
+	    printf("Getting tickets: %s%s%s@%s\n", name,
+		   primary_instance[0] ? "/" : "", 
 		   primary_instance, realm_of_cell);
 	}
 
 	status = get_credv5(context, name, primary_instance, realm_of_cell,
 			    &v5cred);
 
+	if ((status == KRB5KDC_ERR_S_PRINCIPAL_UNKNOWN || status == KRB5KRB_ERR_GENERIC) &&
+	    !realm_of_cell[0]) {
+	    char *afs_realm = afs_realm_of_cell(context, &ak_cellconfig, TRUE);
+
+	    if (!afs_realm) {
+		fprintf(stderr, 
+			"%s: Couldn't figure out realm for cell %s.\n",
+			progname, cell_to_use);
+		exit(AKLOG_MISC);
+	    }
+
+	    strcpy(realm_of_cell, afs_realm);
+
+	    if (strcasecmp(cell_to_use, realm_of_cell) == 0) {
+		try_secondary = 1;
+		secondary_instance[0] = '\0';
+	    }
+
+	    if (dflag) {
+		printf("We've deduced that we need to authenticate to"
+			" realm %s.\n", realm_of_cell);
+		printf("Getting tickets: %s%s%s@%s\n", name,
+			primary_instance[0] ? "/" : "", 
+			primary_instance, realm_of_cell);
+	    }
+
+	    status = get_credv5(context, name, primary_instance, realm_of_cell,
+				 &v5cred);
+
+	}
 	if (status == KRB5KDC_ERR_S_PRINCIPAL_UNKNOWN || status == KRB5KRB_ERR_GENERIC) {
 	    if (try_secondary) {
 		if (dflag) {
 		    printf("Principal not found, trying alternate "
-			   "service name: %s/%s@%s\n", name,
+			   "service name: %s%s%s@%s\n", name,
+			    secondary_instance[0] ? "/" : "",
 			    secondary_instance, realm_of_cell);
 		}
 		status = get_credv5(context, name, secondary_instance,
@@ -779,8 +815,8 @@ static int auth_to_cell(krb5_context context, char *cell, char *realm)
 			    error_message(status), username, cell_to_use,
 			    status);
 		} else {
-		    printf("created cross-cell entry for %s at %s\n",
-			   username, cell_to_use);
+		    printf("created cross-cell entry for %s (Id %d) at %s\n",
+			   username, id, cell_to_use);
 		    sprintf(username, "AFS ID %d", (int) id);
 		}
 	    }
