@@ -99,6 +99,7 @@
 #define SYS_NAME_ID_sun4x_58		 939
 #define SYS_NAME_ID_sun4x_59		 940
 #define SYS_NAME_ID_sun4x_510		 941
+#define SYS_NAME_ID_sun4x_511		 942
 
 /* Sigh. If I leave a gap here IBM will do this sequentially. If I don't
    they won't allocate sunx86 IDs at all. So leave a gap and pray. */
@@ -106,6 +107,7 @@
 #define SYS_NAME_ID_sunx86_58		 951
 #define SYS_NAME_ID_sunx86_59		 952
 #define SYS_NAME_ID_sunx86_510		 953
+#define SYS_NAME_ID_sunx86_511		 954
 
 #define SYS_NAME_ID_vax_ul4		1003
 #define SYS_NAME_ID_vax_ul40		1004
@@ -237,6 +239,7 @@
 #define SYS_NAME_ID_i386_obsd37		2606
 #define SYS_NAME_ID_i386_obsd38		2607
 #define SYS_NAME_ID_i386_obsd39		2608
+#define SYS_NAME_ID_i386_obsd40         2609
 
 #define SYS_NAME_ID_amd64_linux2        2700
 #define SYS_NAME_ID_amd64_linux22       2701
