@@ -20,13 +20,13 @@
  * to decode the decrypted result. As a side-effect of using the AFS/DFS
  * translator as the intermediary, this program also does not have to access
  * any KRB5 location/configuration information--it just contacts the servers
- * listed in the CellServDB in the usual manner (via ubik_Call).
+ * listed in the CellServDB in the usual manner (via ubik_.
  *
  * This works as follows:
  * 
  * 1. dlog sends a GetTickets request to the intermediary.
  *
- * 2. The intermediary reformats the request as an KRB5 AS request, asking
+ * 2. The intermediary reformats the request as an KRB5 AS request(asking
  *    for a ticket made out to the specified principal, suitable for contacting
  *    the AFS/DFS translator principal. This is determined by the server, and
  *    is by default "afs".
@@ -72,7 +72,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/dauth/dlog.c,v 1.9 2003/07/15 23:14:58 shadow Exp $");
+    ("$Header: /cvs/openafs/src/dauth/Attic/dlog.c,v 1.9.2.1 2006/07/31 17:07:50 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -665,7 +665,7 @@ CommandProc(as, arock)
      */
     reply_p = (adk_reply_ptr) 0;
     error_p = (adk_error_ptr) 0;
-    code = ubik_Call(ADK_GetTicket, ubik_handle, 0,	/* Ubik flags */
+    code = ubik_ADK_GetTicket(ubik_handle, 0,	/* Ubik flags */
 		     name,	/* IN:  Principal: must be exact DCE principal */
 		     nonce,	/* IN:  Input nonce */
 		     lifetime,	/* IN:  lifetime */
