@@ -14,7 +14,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/rx/rx_clock_nt.c,v 1.9.2.3 2006/03/06 03:05:02 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/rx/rx_clock_nt.c,v 1.9.2.4 2006/07/31 21:51:21 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <stdio.h>
@@ -23,15 +23,14 @@ RCSID
 #include <winbase.h>
 #include "rx_clock.h"
 
-void clock_UpdateTime(void);	/* forward reference */
-
 struct clock clock_now;		/* The last elapsed time ready by clock_GetTimer */
 
 /* This is set to 1 whenever the time is read, and reset to 0 whenever
  * clock_NewTime is called.  This is to allow the caller to control the
  * frequency with which the actual time is re-evaluated.
  */
-int clock_haveCurrentTime;
+#undef clock_haveCurrentTime
+int clock_haveCurrentTime = 0;
 
 int clock_nUpdates;		/* The actual number of clock updates */
 static int clockInitialized = 0;
@@ -43,6 +42,7 @@ LARGE_INTEGER rxi_clockFreq;
 #undef clock_UpdateTime
 void clock_UpdateTime(void);
 
+#undef clock_Init
 void
 clock_Init(void)
 {
