@@ -9,7 +9,7 @@
 
 #include <afsconfig.h>
 #ifdef	KERNEL
-#include "../afs/param.h"
+#include "afs/param.h"
 #else
 #include <afs/param.h>
 #endif
@@ -18,33 +18,37 @@
 #include <sys/time_impl.h>
 #endif
 
-RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/rx/rx_event.c,v 1.1.1.7 2002/08/02 04:36:20 hartmans Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/rx/rx_event.c,v 1.14.2.3 2005/04/14 02:31:44 shadow Exp $");
 
 #ifdef KERNEL
 #ifndef UKERNEL
-#include "../afs/afs_osi.h"
+#include "afs/afs_osi.h"
 #else /* !UKERNEL */
-#include "../afs/sysincludes.h"
-#include "../afs/afsincludes.h"
+#include "afs/sysincludes.h"
+#include "afsincludes.h"
 #endif /* !UKERNEL */
-#include "../rx/rx_clock.h"
-#include "../rx/rx_queue.h"
-#include "../rx/rx_event.h"
-#include "../rx/rx_kernel.h"
-#include "../rx/rx_kmutex.h"
+#include "rx/rx_clock.h"
+#include "rx/rx_queue.h"
+#include "rx/rx_event.h"
+#include "rx/rx_kernel.h"
+#include "rx_kmutex.h"
 #ifdef RX_ENABLE_LOCKS
-#include "../rx/rx.h"
+#include "rx/rx.h"
 #endif /* RX_ENABLE_LOCKS */
-#include "../rx/rx_globals.h"
+#include "rx/rx_globals.h"
 #if defined(AFS_SGI_ENV)
-#include "../sys/debug.h"
+#include "sys/debug.h"
 /* These are necessary to get curproc (used by GLOCK asserts) to work. */
-#include "../h/proc.h"
+#include "h/proc.h"
 #if !defined(AFS_SGI64_ENV) && !defined(UKERNEL)
-#include "../h/user.h"
+#include "h/user.h"
 #endif
 extern void *osi_Alloc();
 #endif
+#if defined(AFS_OBSD_ENV)
+#include "h/proc.h"
+#endif
 #else /* KERNEL */
 #include <stdio.h>
 #include "rx_clock.h"
@@ -69,24 +73,24 @@ extern void *osi_Alloc();
 /* All event processing is relative to the apparent current time given by clock_GetTime */
 
 /* This should be static, but event_test wants to look at the free list... */
-struct rx_queue rxevent_free;	   /* It's somewhat bogus to use a doubly-linked queue for the free list */
-struct rx_queue rxepoch_free;	   /* It's somewhat bogus to use a doubly-linked queue for the free list */
-static struct rx_queue rxepoch_queue; /* list of waiting epochs */
-static int rxevent_allocUnit = 10;   /* Allocation unit (number of event records to allocate at one time) */
-static int rxepoch_allocUnit = 10;   /* Allocation unit (number of epoch records to allocate at one time) */
-int rxevent_nFree;		   /* Number of free event records */
-int rxevent_nPosted;	   /* Current number of posted events */
-int rxepoch_nFree;		   /* Number of free epoch records */
-static int (*rxevent_ScheduledEarlierEvent)(); /* Proc to call when an event is scheduled that is earlier than all other events */
-struct xfreelist { 
+struct rx_queue rxevent_free;	/* It's somewhat bogus to use a doubly-linked queue for the free list */
+struct rx_queue rxepoch_free;	/* It's somewhat bogus to use a doubly-linked queue for the free list */
+static struct rx_queue rxepoch_queue;	/* list of waiting epochs */
+static int rxevent_allocUnit = 10;	/* Allocation unit (number of event records to allocate at one time) */
+static int rxepoch_allocUnit = 10;	/* Allocation unit (number of epoch records to allocate at one time) */
+int rxevent_nFree;		/* Number of free event records */
+int rxevent_nPosted;		/* Current number of posted events */
+int rxepoch_nFree;		/* Number of free epoch records */
+static void (*rxevent_ScheduledEarlierEvent) (void);	/* Proc to call when an event is scheduled that is earlier than all other events */
+struct xfreelist {
     void *mem;
     int size;
-    struct xfreelist *next; 
+    struct xfreelist *next;
 };
 static struct xfreelist *xfreemallocs = 0, *xsp = 0;
 
 struct clock rxevent_nextRaiseEvents;	/* Time of next call to raise events */
-int rxevent_raiseScheduled;		/* true if raise events is scheduled */
+int rxevent_raiseScheduled;	/* true if raise events is scheduled */
 
 #ifdef RX_ENABLE_LOCKS
 #ifdef RX_LOCKS_DB
@@ -105,8 +109,8 @@ afs_kmutex_t rxevent_lock;
 
 #include <assert.h>
 pthread_mutex_t rx_event_mutex;
-#define LOCK_EV_INIT assert(pthread_mutex_lock(&rx_event_mutex)==0);
-#define UNLOCK_EV_INIT assert(pthread_mutex_unlock(&rx_event_mutex)==0);
+#define LOCK_EV_INIT assert(pthread_mutex_lock(&rx_event_mutex)==0)
+#define UNLOCK_EV_INIT assert(pthread_mutex_unlock(&rx_event_mutex)==0)
 #else
 #define LOCK_EV_INIT
 #define UNLOCK_EV_INIT
@@ -116,18 +120,17 @@ pthread_mutex_t rx_event_mutex;
 /* Pass in the number of events to allocate at a time */
 int rxevent_initialized = 0;
 void
-rxevent_Init(nEvents, scheduler)
-    int nEvents;
-    int (*scheduler)();
+rxevent_Init(int nEvents, void (*scheduler) (void))
 {
-    LOCK_EV_INIT
+    LOCK_EV_INIT;
     if (rxevent_initialized) {
-	UNLOCK_EV_INIT
+	UNLOCK_EV_INIT;
 	return;
     }
     MUTEX_INIT(&rxevent_lock, "rxevent_lock", MUTEX_DEFAULT, 0);
     clock_Init();
-    if (nEvents) rxevent_allocUnit = nEvents;
+    if (nEvents)
+	rxevent_allocUnit = nEvents;
     queue_Init(&rxevent_free);
     queue_Init(&rxepoch_free);
     queue_Init(&rxepoch_queue);
@@ -137,11 +140,12 @@ rxevent_Init(nEvents, scheduler)
     rxevent_initialized = 1;
     clock_Zero(&rxevent_nextRaiseEvents);
     rxevent_raiseScheduled = 0;
-    UNLOCK_EV_INIT
+    UNLOCK_EV_INIT;
 }
 
 /* Create and initialize new epoch structure */
-struct rxepoch *rxepoch_Allocate(struct clock *when)
+struct rxepoch *
+rxepoch_Allocate(struct clock *when)
 {
     struct rxepoch *ep;
     int i;
@@ -150,17 +154,18 @@ struct rxepoch *rxepoch_Allocate(struct clock *when)
      * and add them to the free queue */
     if (queue_IsEmpty(&rxepoch_free)) {
 #if    defined(AFS_AIX32_ENV) && defined(KERNEL)
-	ep = (struct rxepoch *) rxi_Alloc(sizeof(struct rxepoch));
+	ep = (struct rxepoch *)rxi_Alloc(sizeof(struct rxepoch));
 	queue_Append(&rxepoch_free, &ep[0]), rxepoch_nFree++;
 #else
 	ep = (struct rxepoch *)
-	     osi_Alloc(sizeof(struct rxepoch) * rxepoch_allocUnit);
+	    osi_Alloc(sizeof(struct rxepoch) * rxepoch_allocUnit);
 	xsp = xfreemallocs;
-	xfreemallocs = (struct xfreelist *) osi_Alloc(sizeof(struct xfreelist));
+	xfreemallocs =
+	    (struct xfreelist *)osi_Alloc(sizeof(struct xfreelist));
 	xfreemallocs->mem = (void *)ep;
 	xfreemallocs->size = sizeof(struct rxepoch) * rxepoch_allocUnit;
 	xfreemallocs->next = xsp;
-	for (i = 0; i<rxepoch_allocUnit; i++)
+	for (i = 0; i < rxepoch_allocUnit; i++)
 	    queue_Append(&rxepoch_free, &ep[i]), rxepoch_nFree++;
 #endif
     }
@@ -176,22 +181,31 @@ struct rxepoch *rxepoch_Allocate(struct clock *when)
  * "when" argument specifies when "func" should be called, in clock (clock.h)
  * units. */
 
-struct rxevent *rxevent_Post(struct clock *when, void (*func)(),
-			     void *arg, void *arg1)
+#if 0
+struct rxevent *
+rxevent_Post(struct clock *when,
+	     void (*func) (struct rxevent * event,
+			   struct rx_connection * conn,
+			   struct rx_call * acall), void *arg, void *arg1)
+#else
+static struct rxevent *
+_rxevent_Post(struct clock *when, void (*func) (), void *arg, void *arg1,
+	      int arg2, int newargs)
+#endif
 {
     register struct rxevent *ev, *evqe, *evqpr;
     register struct rxepoch *ep, *epqe, *epqpr;
     int isEarliest = 0;
 
     MUTEX_ENTER(&rxevent_lock);
-    AFS_ASSERT_RXGLOCK();
 #ifdef RXDEBUG
     if (rx_Log_event) {
 	struct clock now;
 	clock_GetTime(&now);
-	fprintf(rx_Log_event, "%d.%d: rxevent_Post(%d.%d, %x, %x)\n", 
-	    (int) now.sec, (int) now.usec, (int) when->sec, 
-	    (int) when->usec, (unsigned int) func, (unsigned int) arg);
+	fprintf(rx_Log_event, "%d.%d: rxevent_Post(%d.%d, %lx, %lx, %lx, %d)\n",
+		(int)now.sec, (int)now.usec, (int)when->sec, (int)when->usec,
+		(unsigned long)func, (unsigned long)arg,
+		(unsigned long)arg1, arg2);
     }
 #endif
 
@@ -223,16 +237,18 @@ struct rxevent *rxevent_Post(struct clock *when, void (*func)(),
     if (queue_IsEmpty(&rxevent_free)) {
 	register int i;
 #if	defined(AFS_AIX32_ENV) && defined(KERNEL)
-	ev = (struct rxevent *) rxi_Alloc(sizeof(struct rxevent));
+	ev = (struct rxevent *)rxi_Alloc(sizeof(struct rxevent));
 	queue_Append(&rxevent_free, &ev[0]), rxevent_nFree++;
 #else
-	ev = (struct rxevent *) osi_Alloc(sizeof(struct rxevent) * rxevent_allocUnit);
+	ev = (struct rxevent *)osi_Alloc(sizeof(struct rxevent) *
+					 rxevent_allocUnit);
 	xsp = xfreemallocs;
-	xfreemallocs = (struct xfreelist *) osi_Alloc(sizeof(struct xfreelist));
+	xfreemallocs =
+	    (struct xfreelist *)osi_Alloc(sizeof(struct xfreelist));
 	xfreemallocs->mem = (void *)ev;
 	xfreemallocs->size = sizeof(struct rxevent) * rxevent_allocUnit;
 	xfreemallocs->next = xsp;
-	for (i = 0; i<rxevent_allocUnit; i++)
+	for (i = 0; i < rxevent_allocUnit; i++)
 	    queue_Append(&rxevent_free, &ev[i]), rxevent_nFree++;
 #endif
     }
@@ -247,9 +263,11 @@ struct rxevent *rxevent_Post(struct clock *when, void (*func)(),
     ev->func = func;
     ev->arg = arg;
     ev->arg1 = arg1;
-    rxevent_nPosted += 1; /* Rather than ++, to shut high-C up
-			   *  regarding never-set variables
-			   */
+    ev->arg2 = arg2;
+    ev->newargs = newargs;
+    rxevent_nPosted += 1;	/* Rather than ++, to shut high-C up
+				 *  regarding never-set variables
+				 */
 
     /* Insert the event into the sorted list of events for this epoch */
     for (queue_ScanBackwards(&ep->events, evqe, evqpr, rxevent)) {
@@ -262,20 +280,33 @@ struct rxevent *rxevent_Post(struct clock *when, void (*func)(),
     }
     /* Insert event at head of current epoch */
     queue_Prepend(&ep->events, ev);
-    if (isEarliest && rxevent_ScheduledEarlierEvent &&
-	(!rxevent_raiseScheduled ||
-	 clock_Lt(&ev->eventTime, &rxevent_nextRaiseEvents))) {
+    if (isEarliest && rxevent_ScheduledEarlierEvent
+	&& (!rxevent_raiseScheduled
+	    || clock_Lt(&ev->eventTime, &rxevent_nextRaiseEvents))) {
 	rxevent_raiseScheduled = 1;
 	clock_Zero(&rxevent_nextRaiseEvents);
 	MUTEX_EXIT(&rxevent_lock);
 	/* Notify our external scheduler */
-	(*rxevent_ScheduledEarlierEvent)();
+	(*rxevent_ScheduledEarlierEvent) ();
 	MUTEX_ENTER(&rxevent_lock);
     }
     MUTEX_EXIT(&rxevent_lock);
     return ev;
 }
 
+struct rxevent *
+rxevent_Post(struct clock *when, void (*func) (), void *arg, void *arg1)
+{
+    return _rxevent_Post(when, func, arg, arg1, 0, 0);
+}
+
+struct rxevent *
+rxevent_Post2(struct clock *when, void (*func) (), void *arg, void *arg1,
+	      int arg2)
+{
+    return _rxevent_Post(when, func, arg, arg1, arg2, 1);
+}
+
 /* Cancel an event by moving it from the event queue to the free list.
  * Warning, the event must be on the event queue!  If not, this should core
  * dump (reference through 0).  This routine should be called using the macro
@@ -285,34 +316,26 @@ struct rxevent *rxevent_Post(struct clock *when, void (*func)(),
 #ifdef RX_ENABLE_LOCKS
 #ifdef RX_REFCOUNT_CHECK
 int rxevent_Cancel_type = 0;
-void rxevent_Cancel_1(ev, call, type)
-    register struct rxevent *ev;
-    register struct rx_call *call;
-    register int type;
-#else /* RX_REFCOUNT_CHECK */
-void rxevent_Cancel_1(ev, call)
-    register struct rxevent *ev;
-    register struct rx_call *call;
-#endif /* RX_REFCOUNT_CHECK */
-#else  /* RX_ENABLE_LOCKS */
-void rxevent_Cancel_1(ev)
-    register struct rxevent *ev;
-#endif /* RX_ENABLE_LOCKS */
+#endif
+#endif
+
+void
+rxevent_Cancel_1(register struct rxevent *ev, register struct rx_call *call,
+		 register int type)
 {
 #ifdef RXDEBUG
     if (rx_Log_event) {
 	struct clock now;
 	clock_GetTime(&now);
-	fprintf(rx_Log_event, "%d.%d: rxevent_Cancel_1(%d.%d, %x, %x)\n", 
-		(int) now.sec, (int) now.usec, (int) ev->eventTime.sec, 
-		(int) ev->eventTime.usec, (unsigned int) ev->func,
-		(unsigned int) ev->arg);
+	fprintf(rx_Log_event, "%d.%d: rxevent_Cancel_1(%d.%d, %lx, %lx)\n",
+		(int)now.sec, (int)now.usec, (int)ev->eventTime.sec,
+		(int)ev->eventTime.usec, (unsigned long)ev->func,
+		(unsigned long)ev->arg);
     }
 #endif
     /* Append it to the free list (rather than prepending) to keep the free
      * list hot so nothing pages out
      */
-    AFS_ASSERT_RXGLOCK();
     MUTEX_ENTER(&rxevent_lock);
     if (!ev) {
 	MUTEX_EXIT(&rxevent_lock);
@@ -328,7 +351,7 @@ void rxevent_Cancel_1(ev)
 	    call->refCount--;
 #ifdef RX_REFCOUNT_CHECK
 	    call->refCDebug[type]--;
-	    if (call->refCDebug[type]<0) {
+	    if (call->refCDebug[type] < 0) {
 		rxevent_Cancel_type = type;
 		osi_Panic("rxevent_Cancel: call refCount < 0");
 	    }
@@ -349,8 +372,8 @@ void rxevent_Cancel_1(ev)
  * and the function returns 1.  If there are is no next epoch, the function
  * returns 0.
  */
-int rxevent_RaiseEvents(next)
-    struct clock *next;
+int
+rxevent_RaiseEvents(struct clock *next)
 {
     register struct rxepoch *ep;
     register struct rxevent *ev;
@@ -358,8 +381,6 @@ int rxevent_RaiseEvents(next)
 
     MUTEX_ENTER(&rxevent_lock);
 
-    AFS_ASSERT_RXGLOCK();
-
     /* Events are sorted by time, so only scan until an event is found that has
      * not yet timed out */
 
@@ -387,32 +408,38 @@ int rxevent_RaiseEvents(next)
 	    queue_Remove(ev);
 	    rxevent_nPosted--;
 	    MUTEX_EXIT(&rxevent_lock);
-	    ev->func(ev, ev->arg, ev->arg1);
+	    if (ev->newargs) {
+		ev->func(ev, ev->arg, ev->arg1, ev->arg2);
+	    } else {
+		ev->func(ev, ev->arg, ev->arg1);
+	    }
 	    MUTEX_ENTER(&rxevent_lock);
 	    queue_Append(&rxevent_free, ev);
 	    rxevent_nFree++;
 	} while (queue_IsNotEmpty(&ep->events));
     }
 #ifdef RXDEBUG
-    if (rx_Log_event) fprintf(rx_Log_event, "rxevent_RaiseEvents(%d.%d)\n", 
-	(int) now.sec, (int) now.usec);
+    if (rx_Log_event)
+	fprintf(rx_Log_event, "rxevent_RaiseEvents(%d.%d)\n", (int)now.sec,
+		(int)now.usec);
 #endif
     rxevent_raiseScheduled = 0;
     MUTEX_EXIT(&rxevent_lock);
     return 0;
 }
 
-void shutdown_rxevent(void) 
+void
+shutdown_rxevent(void)
 {
     struct xfreelist *xp, *nxp;
 
-    LOCK_EV_INIT
+    LOCK_EV_INIT;
     if (!rxevent_initialized) {
-	UNLOCK_EV_INIT
+	UNLOCK_EV_INIT;
 	return;
     }
     rxevent_initialized = 0;
-    UNLOCK_EV_INIT
+    UNLOCK_EV_INIT;
     MUTEX_DESTROY(&rxevent_lock);
 #if	defined(AFS_AIX32_ENV) && defined(KERNEL)
     /* Everything is freed in afs_osinet.c */
@@ -424,7 +451,7 @@ void shutdown_rxevent(void)
 	osi_Free((char *)xp, sizeof(struct xfreelist));
 	xp = nxp;
     }
-    xfreemallocs = (struct xfreelist *) 0;
+    xfreemallocs = NULL;
 #endif
 
 }
