@@ -48,9 +48,10 @@ static int newVLDB = 1;
 
 #include <afsconfig.h>
 #include <afs/param.h>
+#include <afs/afsutil.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/vol/fssync.c,v 1.26.2.1 2004/08/25 07:14:19 shadow Exp $");
+    ("$Header: /cvs/openafs/src/vol/Attic/fssync.c,v 1.26.2.6 2007/02/08 23:59:47 shadow Exp $");
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -94,6 +95,10 @@ RCSID
 #include "volume.h"
 #include "partition.h"
 
+#ifdef USE_UNIX_SOCKETS
+#include <sys/un.h>
+#endif
+
 /*@printflike@*/ extern void Log(const char *format, ...);
 
 #ifdef osi_Assert
@@ -159,7 +164,11 @@ struct Lock FSYNC_handler_lock;
 int
 FSYNC_clientInit(void)
 {
+#ifdef USE_UNIX_SOCKETS
+    struct sockaddr_un addr;
+#else /* USE_UNIX_SOCKETS */
     struct sockaddr_in addr;
+#endif /* USE_UNIX_SOCKETS */
     /* I can't believe the following is needed for localhost connections!! */
     static time_t backoff[] =
 	{ 3, 3, 3, 5, 5, 5, 7, 15, 16, 24, 32, 40, 48, 0 };
@@ -169,18 +178,10 @@ FSYNC_clientInit(void)
 	FS_sd = getport(&addr);
 	if (connect(FS_sd, (struct sockaddr *)&addr, sizeof(addr)) >= 0)
 	    return 1;
-#if defined(AFS_SGI_ENV)
-	/* down with worthless error messages! */
-	if (!*timeout) {
-	    perror("FSYNC_clientInit failed (after many retries)");
-	    break;
-	}
-#else
 	if (!*timeout)
 	    break;
 	if (!(*timeout & 1))
-	    perror("FSYNC_clientInit temporary failure (will retry)");
-#endif
+	    Log("FSYNC_clientInit temporary failure (will retry)");
 	FSYNC_clientFinis();
 	sleep(*timeout++);
     }
@@ -197,7 +198,6 @@ FSYNC_clientFinis(void)
     close(FS_sd);
 #endif
     FS_sd = -1;
-    Lock_Destroy(&FSYNC_handler_lock);
 }
 
 int
@@ -269,6 +269,23 @@ FSYNC_fsInit(void)
 #endif /* AFS_PTHREAD_ENV */
 }
 
+#ifdef USE_UNIX_SOCKETS
+static int
+getport(struct sockaddr_un *addr)
+{
+    int sd;
+    char tbuffer[AFSDIR_PATH_MAX]; 
+
+    strcompose(tbuffer, AFSDIR_PATH_MAX, AFSDIR_SERVER_LOCAL_DIRPATH, "/",
+               "fssync.sock", NULL);
+
+    memset(addr, 0, sizeof(*addr));
+    addr->sun_family = AF_UNIX;
+    strncpy(addr->sun_path, tbuffer, (sizeof(struct sockaddr_un) - sizeof(short)));
+    assert((sd = socket(AF_UNIX, SOCK_STREAM, 0)) >= 0);
+    return sd;
+}
+#else  /* USE_UNIX_SOCKETS */
 static int
 getport(struct sockaddr_in *addr)
 {
@@ -285,13 +302,18 @@ getport(struct sockaddr_in *addr)
 
     return sd;
 }
+#endif
 
 static fd_set FSYNC_readfds;
 
 static void
 FSYNC_sync()
 {
+#ifdef USE_UNIX_SOCKETS
+    struct sockaddr_un addr;
+#else  /* USE_UNIX_SOCKETS */
     struct sockaddr_in addr;
+#endif /* USE_UNIX_SOCKETS */
     int on = 1;
     extern VInit;
     int code;
@@ -299,6 +321,9 @@ FSYNC_sync()
 #ifdef AFS_PTHREAD_ENV
     int tid;
 #endif
+#ifdef USE_UNIX_SOCKETS
+    char tbuffer[AFSDIR_PATH_MAX]; 
+#endif
 
 #ifndef AFS_NT40_ENV
     (void)signal(SIGPIPE, SIG_IGN);
@@ -313,6 +338,13 @@ FSYNC_sync()
     Log("Set thread id %d for FSYNC_sync\n", tid);
 #endif /* AFS_PTHREAD_ENV */
 
+#ifdef USE_UNIX_SOCKETS
+    strcompose(tbuffer, AFSDIR_PATH_MAX, AFSDIR_SERVER_LOCAL_DIRPATH, "/",
+               "fssync.sock", NULL);
+    /* ignore errors */
+    remove(tbuffer);
+#endif /* USE_UNIX_SOCKETS */
+
     while (!VInit) {
 	/* Let somebody else run until level > 0.  That doesn't mean that 
 	 * all volumes have been attached. */
